@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Maven::Maven;
-$Maven::Maven::VERSION = '1.06';
+$Maven::Maven::VERSION = '1.07';
 # ABSTRACT: The main interface to maven
 # PODNAME: Maven::Maven
 
@@ -97,6 +97,10 @@ sub get_repositories {
     return $_[0]->{repositories};
 }
 
+sub get_settings {
+    return $_[0]->{settings};
+}
+
 sub _is_active_profile {
     my ( $self, $profile ) = @_;
 }
@@ -185,7 +189,7 @@ Maven::Maven - The main interface to maven
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -256,6 +260,10 @@ Returns the value of the effective settings property indicated by C<$key>.
 
 Returns the repositories configured in the effective settings.
 
+=head2 get_settings()
+
+Returns the resolved maven settings (combines global and user settings).
+
 =head2 m2_home([@parts])
 
 Returns a path indicated by joining all of C<@parts> to the maven install
