@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Maven::MvnAgent;
-$Maven::MvnAgent::VERSION = '1.06';
+$Maven::MvnAgent::VERSION = '1.07';
 # ABSTRACT: An agent for downloading artifacts using the mvn command
 # PODNAME: Maven::MvnAgent
 
@@ -36,6 +36,13 @@ sub _artifact_command {
             ? Cygwin::posix_to_win_path($file)
             : $file;
     }
+    if ( !$maven_options->{'--global-settings'} ) {
+        my $file = $self->{maven}->m2_home( 'conf', 'settings.xml' );
+        $maven_options->{'--global-settings'} =
+            $^O eq 'cygwin'
+            ? Cygwin::posix_to_win_path($file)
+            : $file;
+    }
     if ( !$maven_options->{'-Duser.home'} ) {
         my $path = $self->{maven}->get_property('user.home');
         $maven_options->{'-Duser.home'} =
@@ -175,7 +182,7 @@ Maven::MvnAgent - An agent for downloading artifacts using the mvn command
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
